pub struct Config { /* private fields */ }Expand description
Represents a complete config file, which can hold multiple Accounts.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn for_account(&self, name: Option<&str>) -> Option<Account<'_>>
pub fn for_account(&self, name: Option<&str>) -> Option<Account<'_>>
Returns a specific account’s configuration.
If name is some string and matches the name of a configured account
returns the corresponding Account. If name is None, returns the
configuration of the first account in the config file. The latter can be
expected to never return None as loading a configuration file fails if
it does not configure at least one account.