pub struct Config { /* private fields */ }
Represents a complete config file, which can hold multiple Accounts
Returns a specific account’s configuration
name
None
TypeId
self
Returns the argument unchanged.
Calls U::from(self).
U::from(self)
That is, this conversion is whatever the implementation of From<T> for U chooses to do.
From<T> for U